<?xml version="1.0" encoding="UTF-8"?>
<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron"
  xmlns:sqf="http://www.schematron-quickfix.com/validator/process" queryBinding="xslt2"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <sch:pattern>
    
    <sch:rule context="title">
      <!-- Title - styling elements are not allowed in title. -->
      <sch:report test="exists(b)" subject="b" role="warn"> 
        Bold element is not allowed in title.</sch:report>

      <!-- Comments are not allowed in the title element -->
      <sch:report test="comment()">
        Comments are not allowed in the title</sch:report>
    </sch:rule>

    <!-- External reference asserts -->
    <sch:rule context="xref[@scope = 'external']">
      <!-- Check that the format attribute is set on an external link. -->
      <sch:assert test="@format">
        An external link needs to have the @format attribute.</sch:assert>
      
      <!-- Check the external link protocol -->
      <sch:assert test="matches(@href, '^http(s?)://')" role="warn">
        An external link should start with http(s).</sch:assert>
    </sch:rule>

    <!-- Unordered list asserts -->
    <sch:rule context="li">
      <!-- The list item must not end with semicolon -->
      <sch:report test="matches(text()[last()], ';$')" role="warn">
        Semicolon is not allowed after list item.</sch:report>
    </sch:rule>
    
    <!-- Table asserts -->
    <sch:rule context="table">
      <sch:let name="minColumsNo" value="min(//row/count(entry))"/>
      <sch:let name="reqColumsNo" value="max(//row/count(entry))"/>
      
      <!-- Check the number of cells on each row -->
      <sch:assert test="$minColumsNo >= $reqColumsNo">Cells are missing. (The
        number of cells for each row must be <sch:value-of select="$reqColumsNo"/>)</sch:assert>
    </sch:rule>
    
    <!-- Ordered list assert -->
    <sch:rule context="ol">
      <sch:assert test="false()">
        Ordered lists are not allowed, use unordered lists instead.</sch:assert>
    </sch:rule>
    
    <sch:rule context="ul">
      <!-- Check the level of nested lists -->
      <sch:report test="count(ancestor::ul) >= 2"> Too many levels in
        this list </sch:report>
      
      <!-- Check that there is more that one lit item in a list -->
      <sch:assert test="count(li) > 1" role="warn"> A list must have more than
        one item </sch:assert>
    </sch:rule>
  </sch:pattern>
</sch:schema>














